====================================
tkBak Backup and Restore Application
====================================

:Author: Konstas Marmatakis <marmako@gmail.com>

:Date: 2014-05-15
:Description: This is an application for backup and restore files.
:Requirements: Requirements
:INSTALL: Installation
:USE: User Manual


Requirements
============

- Windows, Linux, Mac

- Python >= 3.2 with tkinter + ttk (default for windows, Linux users must see the packages)

Installation
============

- Just unzip the zip file to your $HOME folder, or

- There is installer for windows and linux but not fully tested.
  You can use it but with your own risk:

  - Windows: Double click on "\*.exe" setup file, as administrator.

  - Linux: On command line, unzip the \*.zip or \*.tar.gz file, ``cd tkbak-x.z.y``, and as root, type: ``python3 setup.py install``.


User Manual
===========


How to start
------------

Without Installer
~~~~~~~~~~~~~~~~~

On a terminal just type:

- ``cd tkbak`` 
- ``python3 tkbak`` or ``chmod +x tkbak`` and ``./tkbak`` for linux users.

- ``python tkbak`` for windows users.

- On graphical enviroment (windows and linux):
    click or double click on the file tkbak.

With Installer
~~~~~~~~~~~~~~

**Windows:** Just click on the icon Tkbak desktop or in start menu the same icon.

**Linux:**  Click on the icon Tkbak on the utilities menu.


Manual
------
The application has these features:

- To compress the selected files and folders to zip or tar.gz file.
- To restore these compressed files.
- To add files in existicting compressed files.

- Save the source files and directories for repeating the former tasks.

Languages
---------

 - Greek
 - English

If you want to translate in your language, please contact with me.
